@@ -21,7 +21,7 @@ def run_tests(*test_args):
     # Import django tests runner
     from django.test.simple import DjangoTestSuiteRunner
     if not test_args:
-        test_args = ['main', 'simple']
+        test_args = ['main', 'simple', 'rpc']
     parent = dirname(abspath(__file__))
     sys.path.insert(0, parent)
     tests_runner = DjangoTestSuiteRunner(verbosity=1, interactive=True, failfast=True)
